==> owncloud-10.0.7.tgz: owncloud/settings/l10n/es_AR.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Clave incorrecta",
    "No user supplied" : "No se ha indicado el usuario",
    "Authentication error" : "Error al autenticar",
    "Wrong admin recovery password. Please check the password and try again." : "Contraseña de recuperación administrativa incorrecta. Por favor, chequee la clave e intente de nuevo",
    "Unable to change password" : "Imposible cambiar la contraseña",
    "Saved" : "Guardado",
    "test email settings" : "Configuración de correo de prueba.",
    "Email sent" : "e-mail mandado",
    "You need to set your user email before being able to send test emails." : "Necesita especificar el usuario de correo electrónico antes de poder enviar correos electrónicos de prueba.",
    "Your full name has been changed." : "Su nombre completo ha sido cambiado.",
    "Unable to change full name" : "Imposible cambiar el nombre completo",
    "APCu" : "APCu",
    "__language_name__" : "Castellano (Argentina)",
    "Language changed" : "Idioma cambiado",
    "Invalid request" : "Pedido inválido",
    "Admins can't remove themself from the admin group" : "Los administradores no se pueden quitar a si mismos del grupo administrador. ",
    "All" : "Todos",
    "Enabled" : "Habilitado",
    "Please wait...." : "Por favor, esperá....",
    "Error while disabling app" : "Se ha producido un error mientras se deshabilitaba la aplicación",
    "Disable" : "Desactivar",
    "Enable" : "Activar",
    "Error while enabling app" : "Se ha producido un error mientras se habilitaba la aplicación",
    "Updating...." : "Actualizando....",
    "Error while updating app" : "Error al actualizar App",
    "Updated" : "Actualizado",
    "Delete" : "Borrar",
    "Sending..." : "Enviando...",
    "Select a profile picture" : "Seleccionar una imágen de perfil",
    "Very weak password" : "Contraseña muy débil.",
    "Weak password" : "Contraseña débil.",
    "So-so password" : "Contraseña de nivel medio. ",
    "Good password" : "Buena contraseña. ",
    "Strong password" : "Contraseña fuerte.",
    "Groups" : "Grupos",
    "undo" : "deshacer",
    "never" : "nunca",
    "add group" : "agregar grupo",
    "enabled" : "activado",
    "disabled" : "desactivado",
    "A valid username must be provided" : "Debe ingresar un nombre de usuario válido",
    "A valid password must be provided" : "Debe ingresar una contraseña válida",
    "Cheers!" : "¡Saludos!",
    "Forum" : "Foro",
    "Documentation:" : "Documentación:",
    "Cron" : "Cron",
    "Execute one task with each page loaded" : "Ejecutá una tarea con cada pagina cargada.",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php está registrado en el servicio webcron para llamarlo cada 15 minutos usando http.",
    "Sharing" : "Compartiendo",
    "Allow apps to use the Share API" : "Permitir a las aplicaciones usar la Share API",
    "Allow public uploads" : "Permitir subidas públicas",
    "Allow users to send mail notification for shared files" : "Habilitar a los usuarios para enviar notificaciones por correo para archivos compartidos",
    "Allow resharing" : "Permitir Re-Compartir",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Todo (notificaciones fatales, errores, advertencias, info, debug)",
    "Info, warnings, errors and fatal issues" : "Info, advertencias, errores y notificaciones fatales",
    "Warnings, errors and fatal issues" : "Advertencias, errores y notificaciones fatales",
    "Errors and fatal issues" : "Errores y notificaciones fatales",
    "Fatal issues only" : "Notificaciones fatales solamente",
    "Log" : "Log",
    "None" : "Ninguno",
    "Login" : "Ingresar",
    "Plain" : "Plano",
    "NT LAN Manager" : "Administrador NT LAN",
    "This is used for sending out notifications." : "Esto es usado para enviar notificaciones.",
    "Send mode" : "Modo de envio",
    "Encryption" : "Encriptación",
    "From address" : "Dirección remitente",
    "Authentication method" : "Método de autenticación",
    "Authentication required" : "Autentificación requerida",
    "Server address" : "Dirección del servidor",
    "Port" : "Puerto",
    "Credentials" : "Credenciales",
    "SMTP Username" : "Nombre de usuario SMTP",
    "SMTP Password" : "Contraseña SMTP",
    "Test email settings" : "Configuracion de correo de prueba.",
    "Send email" : "Enviar correo",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "El módulo PHP 'fileinfo' no existe. Es recomendable que actives este módulo para obtener mejores resultados con la detección mime-type",
    "System locale can not be set to a one which supports UTF-8." : "La localización del sistema no puede cambiarse a una que soporta UTF-8",
    "This means that there might be problems with certain characters in file names." : "Esto significa que puede haber problemas con ciertos caracteres en los nombres de archivos.",
    "Get the apps to sync your files" : "Obtené Apps para sincronizar tus archivos",
    "Desktop client" : "Cliente de escritorio",
    "Android app" : "App para Android",
    "iOS app" : "App para iOS",
    "Show First Run Wizard again" : "Mostrar de nuevo el asistente de primera ejecución",
    "Profile picture" : "Imágen de perfil",
    "Upload new" : "Subir nuevo",
    "Remove image" : "Remover imagen",
    "Cancel" : "Cancelar",
    "Email" : "e-mail",
    "Your email address" : "Tu dirección de e-mail",
    "Password" : "Contraseña",
    "Unable to change your password" : "No fue posible cambiar tu contraseña",
    "Current password" : "Contraseña actual",
    "New password" : "Nueva contraseña:",
    "Change password" : "Cambiar contraseña",
    "Language" : "Idioma",
    "Help translate" : "Ayudanos a traducir",
    "Unlimited" : "Ilimitado",
    "Name" : "Nombre",
    "Username" : "Nombre de usuario",
    "Version" : "Versión",
    "Personal" : "Personal",
    "Admin" : "Administración",
    "Error" : "Error",
    "Create" : "Crear",
    "Admin Recovery Password" : "Recuperación de contraseña de administrador",
    "Enter the recovery password in order to recover the users files during password change" : "Ingresá la contraseña de recuperación para recuperar los archivos de usuario al cambiar contraseña",
    "Group" : "Grupo",
    "Default Quota" : "Cuota predeterminada",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Por favor ingrese la cuota de almacenamiento (ej.: \"512 MB\" o \"12 GB\")",
    "Other" : "Otros",
    "Full Name" : "Nombre completo",
    "Quota" : "Cuota",
    "change full name" : "Cambiar nombre completo",
    "set new password" : "Configurar nueva contraseña",
    "Default" : "Predeterminado"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.10.tgz: owncloud/settings/l10n/es_AR.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Clave incorrecta",
    "No user supplied" : "No se ha indicado el usuario",
    "Authentication error" : "Error al autenticar",
    "Wrong admin recovery password. Please check the password and try again." : "Contraseña de recuperación administrativa incorrecta. Por favor, chequee la clave e intente de nuevo",
    "Unable to change password" : "Imposible cambiar la contraseña",
    "Saved" : "Guardado",
    "test email settings" : "Configuración de correo de prueba.",
    "Email sent" : "e-mail mandado",
    "You need to set your user email before being able to send test emails." : "Necesita especificar el usuario de correo electrónico antes de poder enviar correos electrónicos de prueba.",
    "Your full name has been changed." : "Su nombre completo ha sido cambiado.",
    "Unable to change full name" : "Imposible cambiar el nombre completo",
    "APCu" : "APCu",
    "__language_name__" : "Castellano (Argentina)",
    "Language changed" : "Idioma cambiado",
    "Invalid request" : "Pedido inválido",
    "Admins can't remove themself from the admin group" : "Los administradores no se pueden quitar a si mismos del grupo administrador. ",
    "All" : "Todos",
    "Enabled" : "Habilitado",
    "Please wait...." : "Por favor, esperá....",
    "Error while disabling app" : "Se ha producido un error mientras se deshabilitaba la aplicación",
    "Disable" : "Desactivar",
    "Enable" : "Activar",
    "Error while enabling app" : "Se ha producido un error mientras se habilitaba la aplicación",
    "Updating...." : "Actualizando....",
    "Error while updating app" : "Error al actualizar App",
    "Updated" : "Actualizado",
    "Delete" : "Borrar",
    "Sending..." : "Enviando...",
    "Select a profile picture" : "Seleccionar una imágen de perfil",
    "Very weak password" : "Contraseña muy débil.",
    "Weak password" : "Contraseña débil.",
    "So-so password" : "Contraseña de nivel medio. ",
    "Good password" : "Buena contraseña. ",
    "Strong password" : "Contraseña fuerte.",
    "Groups" : "Grupos",
    "undo" : "deshacer",
    "never" : "nunca",
    "add group" : "agregar grupo",
    "enabled" : "activado",
    "disabled" : "desactivado",
    "A valid username must be provided" : "Debe ingresar un nombre de usuario válido",
    "A valid password must be provided" : "Debe ingresar una contraseña válida",
    "Cheers!" : "¡Saludos!",
    "Forum" : "Foro",
    "Documentation:" : "Documentación:",
    "Cron" : "Cron",
    "Execute one task with each page loaded" : "Ejecutá una tarea con cada pagina cargada.",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php está registrado en el servicio webcron para llamarlo cada 15 minutos usando http.",
    "Sharing" : "Compartiendo",
    "Allow apps to use the Share API" : "Permitir a las aplicaciones usar la Share API",
    "Allow public uploads" : "Permitir subidas públicas",
    "Allow users to send mail notification for shared files" : "Habilitar a los usuarios para enviar notificaciones por correo para archivos compartidos",
    "Allow resharing" : "Permitir Re-Compartir",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Todo (notificaciones fatales, errores, advertencias, info, debug)",
    "Info, warnings, errors and fatal issues" : "Info, advertencias, errores y notificaciones fatales",
    "Warnings, errors and fatal issues" : "Advertencias, errores y notificaciones fatales",
    "Errors and fatal issues" : "Errores y notificaciones fatales",
    "Fatal issues only" : "Notificaciones fatales solamente",
    "Log" : "Log",
    "None" : "Ninguno",
    "Login" : "Ingresar",
    "Plain" : "Plano",
    "NT LAN Manager" : "Administrador NT LAN",
    "This is used for sending out notifications." : "Esto es usado para enviar notificaciones.",
    "Send mode" : "Modo de envio",
    "Encryption" : "Encriptación",
    "From address" : "Dirección remitente",
    "Authentication method" : "Método de autenticación",
    "Authentication required" : "Autentificación requerida",
    "Server address" : "Dirección del servidor",
    "Port" : "Puerto",
    "Credentials" : "Credenciales",
    "SMTP Username" : "Nombre de usuario SMTP",
    "SMTP Password" : "Contraseña SMTP",
    "Test email settings" : "Configuracion de correo de prueba.",
    "Send email" : "Enviar correo",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "El módulo PHP 'fileinfo' no existe. Es recomendable que actives este módulo para obtener mejores resultados con la detección mime-type",
    "System locale can not be set to a one which supports UTF-8." : "La localización del sistema no puede cambiarse a una que soporta UTF-8",
    "This means that there might be problems with certain characters in file names." : "Esto significa que puede haber problemas con ciertos caracteres en los nombres de archivos.",
    "Get the apps to sync your files" : "Obtené Apps para sincronizar tus archivos",
    "Desktop client" : "Cliente de escritorio",
    "Android app" : "App para Android",
    "iOS app" : "App para iOS",
    "Show First Run Wizard again" : "Mostrar de nuevo el asistente de primera ejecución",
    "Profile picture" : "Imágen de perfil",
    "Upload new" : "Subir nuevo",
    "Remove image" : "Remover imagen",
    "Cancel" : "Cancelar",
    "Email" : "e-mail",
    "Your email address" : "Tu dirección de e-mail",
    "Password" : "Contraseña",
    "Unable to change your password" : "No fue posible cambiar tu contraseña",
    "Current password" : "Contraseña actual",
    "New password" : "Nueva contraseña:",
    "Change password" : "Cambiar contraseña",
    "Language" : "Idioma",
    "Help translate" : "Ayudanos a traducir",
    "Unlimited" : "Ilimitado",
    "Name" : "Nombre",
    "Username" : "Nombre de usuario",
    "Version" : "Versión",
    "Personal" : "Personal",
    "Admin" : "Administración",
    "Error" : "Error",
    "Create" : "Crear",
    "Admin Recovery Password" : "Recuperación de contraseña de administrador",
    "Enter the recovery password in order to recover the users files during password change" : "Ingresá la contraseña de recuperación para recuperar los archivos de usuario al cambiar contraseña",
    "Group" : "Grupo",
    "Default Quota" : "Cuota predeterminada",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Por favor ingrese la cuota de almacenamiento (ej.: \"512 MB\" o \"12 GB\")",
    "Other" : "Otros",
    "Full Name" : "Nombre completo",
    "Quota" : "Cuota",
    "change full name" : "Cambiar nombre completo",
    "set new password" : "Configurar nueva contraseña",
    "Default" : "Predeterminado",
    "Share" : "Compartir",
    "Open documentation" : "Abrir documentación",
    "days" : "días",
    "What to log" : "Que registrar",
    "Add" : "Agregar",
    "Download logfile (%s)" : "Descargar archivo de registro (1%s)",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "El archivo de registro es mayor a 100 MB. La descarga tomara un tiempo!",
    "Email has been changed successfully." : "La dirección de correo se ha modificado satisfactoriamente.",
    "Unable to change mail address" : "No se puede modificar la dirección de correo."
},
"nplurals=2; plural=(n != 1);");
